@@ -1,6 +1,6 @@
 package Dancer2::Plugin::FormValidator;
 
-use 5.20.0;
+use 5.24.0;
 
 use Dancer2::Plugin;
 use Dancer2::Core::Hook;
@@ -13,9 +13,9 @@ use Hash::Util qw(lock_hashref);
 use Module::Load;
 use Types::Standard qw(InstanceOf HashRef);
 
-our $VERSION = '0.22';
+our $VERSION = '0.30';
 
-plugin_keywords qw(validate_form validate errors validator_language);
+plugin_keywords qw(validate_form errors validator_language);
 
 has config_obj => (
     is       => 'ro',
@@ -131,10 +131,10 @@ sub _registry {
     # First build extensions.
     my @extensions = map
     {
-        my $class = $self->extensions->{$_}->{provider};
-        autoload $class;
+        my $extension = $self->extensions->{$_}->{provider};
+        autoload $extension;
 
-        $class->new(
+        $extension->new(
             plugin => $self,
             config => $self->extensions->{$_},
         );
@@ -169,7 +169,7 @@ Dancer2::Plugin::FormValidator - neat and easy to start form validation plugin f
 
 =head1 VERSION
 
-version 0.22
+version 0.30
 
 =head1 SYNOPSIS
 
@@ -228,6 +228,7 @@ Help is always welcome!
 This is micro-framework that provides validation in your Dancer2 application.
 It consists of dsl's keywords and a set of agreements.
 It has a set of built-in validators that can be extended by compatible modules (extensions).
+Also proved runtime switching between languages, so you can show proper error messages to users.
 
 Uses simple and declarative approach to validate forms:
 
@@ -355,7 +356,9 @@ Template app/register:
                 support_form: 'App::Http::Validators::SupportForm'
                 ...
             extensions:
-                Upload: ...
+                upload:
+                    provider: ...
+                    ...
     ...
 
 =head1 DSL KEYWORDS
@@ -364,7 +367,7 @@ Template app/register:
 
     my $valid_hash_ref = validate_form $form
 
-Returns $valid_hash_ref if validation succeed, otherwise rerurns undef.
+Returns $valid_hash_ref if validation succeed, otherwise returns undef.
 
 =head3 validator_language
 
@@ -374,20 +377,26 @@ Returns $valid_hash_ref if validation succeed, otherwise rerurns undef.
 
     my $errors_hash_multi = errors
 
+Returns HashRef[ArrayRef] if validation failed.
+
 =head1 Validators
 
 =head3 accepted
 
 =head3 alpha
+
 Validate that string only contain of alphabetic utf8 symbols, i.e. /^[[:alpha:]]+$/.
 
 =head3 alpha_ascii
+
 Validate that string only contain of latin alphabetic ascii symbols, i.e. /^[[:alpha:]]+$/a.
 
 =head3 alpha_num
+
 Validate that string only contain of alphabetic utf8 symbols, underscore and numbers 0-9, i.e. /^\w+$/.
 
 =head3 alpha_num_ascii
+
 Validate that string only contain of latin alphabetic ascii symbols, underscore and numbers 0-9, i.e. /^\w+$/a.
 
 =head3 email
