@@ -1,7 +1,7 @@
 package Dancer2::Plugin::FormValidator::Result;
 
 use Moo;
-use Types::Standard qw(ArrayRef HashRef Bool Str Undef);
+use Types::Standard qw(ArrayRef HashRef Bool);
 use namespace::clean;
 
 has success => (
@@ -10,12 +10,6 @@ has success => (
     required => 1,
 );
 
-has missing => (
-    is       => 'ro',
-    isa      => ArrayRef,
-    required => 1,
-);
-
 has invalid => (
     is       => 'ro',
     isa      => ArrayRef,
@@ -30,7 +24,7 @@ has valid => (
 
 has messages => (
     is       => 'ro',
-    isa      => Undef | Str | HashRef,
+    isa      => HashRef,
     required => 1,
 );
 
